module RechnMgmUserArea
    class ApplicationController < ActionController::Base
        protect_from_forgery with: :exception

        NotAuthorised = Class.new(StandardError)

        rescue_from RechnMgmUserArea::ApplicationController::NotAuthorised do
            render_error_page(status: 403, text: 'Forbidden')
        end

        before_action :add_x_frame_options if Rails.env.development?
        before_action :set_membership

        private
        def add_x_frame_options
            response.headers['X-FRAME-OPTIONS'] = 'ALLOWALL'
        end

        def set_membership
            # set membership if organisation was set by the token
            raise RechnMgmUserArea::ApplicationController::NotAuthorised if current_user.nil?

            token = Warden::JWTAuth::HeaderParser.from_env(request.headers)
            return if token.nil?

            payload = Warden::JWTAuth::TokenDecoder.new.call(token)
            current_user.current_membership_id = payload["membership_id"]
        end

        def render_error_page(status:, text:, template: 'errors/routing')
            respond_to do |format|
                format.json { render json: {errors: [message: "#{status} #{text}"]}, status: status }
                format.html { render template: template, status: status, layout: false }
                format.any  { head status }
            end
        end
    end
end
